OC.L10N.register(
    "core",
    {
    "Please select a file." : "Velg en fil.",
    "File is too big" : "Filen er for stor",
    "The selected file is not an image." : "Den valgte filen er ikke et bilde.",
    "The selected file cannot be read." : "Den valgte filen kan ikke leses.",
    "The file was uploaded" : "Filen ble lastet opp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Filen er større enn definert grense i upload_max_filesize satt i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Filen er større enn definert grense i MAX_FILE_SIZE  satt i HTML-formen.",
    "The file was only partially uploaded" : "Filen ble kun delvis opplastet",
    "No file was uploaded" : "Ingen fil var lastet opp",
    "Missing a temporary folder" : "Mangler midlertidig mappe",
    "Could not write file to disk" : "Skriving til disk mislyktes",
    "A PHP extension stopped the file upload" : "En PHP-utvidelse stoppet filopplastingen.",
    "Invalid file provided" : "Ugyldig fil oppgitt",
    "No image or file provided" : "Ikke noe bilde eller fil angitt",
    "Unknown filetype" : "Ukjent filtype",
    "An error occurred. Please contact your admin." : "Det oppsto en feil. Kontakt din administrator.",
    "Invalid image" : "Ugyldig bilde",
    "No temporary profile picture available, try again" : "Midlertidig profilbilde ikke tilgjengelig. Prøv igjen",
    "No crop data provided" : "Ingen beskjæringsinformasjon angitt",
    "No valid crop data provided" : "Ingen gyldige beskjæringsdata oppgitt",
    "Crop is not square" : "Beskjæringen er ikke kvadratisk",
    "State token does not match" : "Tilstandsnøkkel samsvarer ikke",
    "Invalid app password" : "Ugyldig programpassord",
    "Could not complete login" : "Kunne ikke fullføre pålogging",
    "State token missing" : "Tilstandsnøkkel mangler",
    "Your login token is invalid or has expired" : "Innloggingen din er ugyldig eller utgått",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Denne fellesskapsutgaven av Nextcloud støttes ikke og push-varslinger er begrenset.",
    "Login" : "Logg inn",
    "Password reset is disabled" : "Tilbakestilling av passord er avskrudd",
    "Could not reset password because the token is expired" : "Kan ikke tilbakestille passordet fordi token er utgått.",
    "Could not reset password because the token is invalid" : "Kan ikke tilbakestille passordet fordi token er ugyldig.",
    "Password is too long. Maximum allowed length is 469 characters." : "Passordet er for langt. Maksimal tillatt lengde er 469 tegn.",
    "%s password reset" : "%s tilbakestilling av passord",
    "Password reset" : "Tilbakestilling av passord",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klikk følgende knapp for å tilbakestille passordet ditt. Ignorer denne e-posten hvis du ikke har forespurt dette.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klikk følgende lenke for å tilbakestille passordet ditt. Ignorer denne e-posten hvis du ikke har forespurt dette.",
    "Reset your password" : "Tilbakestill passordet ditt",
    "Requested task type does not exist" : "Den forespurte oppgavetypen eskisterer ikke",
    "Necessary language model provider is not available" : "Nødvendig tilbyder av språkmodell er ikke tilgjengelig",
    "Task not found" : "Oppgave ikke funnet",
    "Internal error" : "Intern feil",
    "No text to image provider is available" : "Ingen tilbyder av tekst til bilde er tilgjengelig",
    "Image not found" : "Bilde ikke funnet",
    "No translation provider available" : "Ingen tilbyder av oversetting er tilgjengelig",
    "Could not detect language" : "Kunne ikke gjenkjenne srpåk",
    "Unable to translate" : "Ikke i stand til å oversette",
    "Nextcloud Server" : "Nextcloud-server",
    "Some of your link shares have been removed" : "Noen av de delte lenkene dine har blitt fjernet",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grunn av et sikkerhetsproblem har vi fjernet enkelte av de delte lenkene dine. Vennligst se linken for mer informasjon. ",
    "The account limit of this instance is reached." : "Kontogrensen for denne forekomsten er nådd.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Skriv inn abonnementsnøkkelen din i støtteappen for å øke brukergrensen. Dette gir deg også alle tilleggsfordeler som Nextcloud Enterprise tilbyr og anbefales på det sterkeste for driften i selskaper.",
    "Learn more ↗" : "Lær mer ↗",
    "Preparing update" : "Forbereder oppdatering",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Reparasjonstrinn:",
    "Repair info:" : "Reparasjonsinformasjon:",
    "Repair warning:" : "Reparasjonsadvarsel:",
    "Repair error:" : "Reparasjonsfeil:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Vennligst bruk kommandolinje til å oppdatere.  Oppdatering via nettleser er ikke aktivert i din config.php.",
    "Turned on maintenance mode" : "Vedlikeholdmodus aktivt",
    "Turned off maintenance mode" : "Vedlikeholdmodus er deaktivert",
    "Maintenance mode is kept active" : "Vedlikeholdmodus beholdes aktivt",
    "Updating database schema" : "Oppdaterer database-skjemaet",
    "Updated database" : "Database er oppdatert",
    "Update app \"%s\" from App Store" : "Oppdater appen \"%s\" fra appbutikk",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Sjekker om databaseskjemaet for %s kan oppdateres (dette kan ta lang tid hvis databasen er stor)",
    "Updated \"%1$s\" to %2$s" : "Oppdaterte \"%1$s\" til %2$s",
    "Set log level to debug" : "Sett loggnivå for feilsøking",
    "Reset log level" : "Standard loggnivå",
    "Starting code integrity check" : "Starter sjekk av kode-integritet",
    "Finished code integrity check" : "Fullførte sjekk av kodeintegritet",
    "%s (incompatible)" : "%s (ikke kompatibel)",
    "The following apps have been disabled: %s" : "Følgende apper har blitt deaktivert: %s",
    "Already up to date" : "Allerede oppdatert",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Webserveren din er ikke satt opp til å tillate synkronisering av filer ennå, fordi WebDAV-grensesnittet ikke ser ut til å virke.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Din web-server er ikke satt opp korrekt for å hente \"{url}\". Mer informasjon finner du i <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentasjonen</a>.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Du får tilgang til forekomsten din via en sikker tilkobling, men forekomsten genererer usikre nettadresser. Dette betyr mest sannsynlig at du står bak en omvendt proxy og at overskrivingskonfigurasjonsvariablene ikke er satt riktig. Les {linkstart}dokumentasjonssiden om dette ↗{linkend}.",
    "Error occurred while checking server setup" : "Feil oppsto ved sjekking av server-oppsett",
    "For more details see the {linkstart}documentation ↗{linkend}." : "For mer informasjon se {linkstart}dokumentasjonen ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Datakatalogen og filene dine er sannsynligvis tilgjengelige fra internett. .htaccess-filen fungerer ikke. Det anbefales på det sterkeste at du konfigurerer webserveren slik at datakatalogen ikke lenger er tilgjengelig, eller flytter datakatalogen utenfor webserverens dokumentrot.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-hodet \"{header}\" er ikke satt opp likt \"{expected}\". Dette kan være en sikkerhet- eller personvernsrisiko og det anbefales at denne innstillingen endres.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-hodet \"{header}\" er ikke satt opp til å være likt \"{expected}\". Det kan hende noen funksjoner ikke fungerer rett, og det anbefales å justere denne innstillingen henholdsvis.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-hodet \"{header}\" inneholder ikke \"{expected}\". Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen deretter.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP-hodet «{header}» er ikke satt til «{val1}», «{val2}», «{val3}», «{val4}» eller «{val5}». Dette kan lekke refererinformasjon. Se {linkstart}W3C-anbefalingen ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP-headeren \"Strict-Transport-Security\" er ikke satt til minst \"{seconds}\" sekunder. For økt sikkerhet anbefales det å aktivere HSTS som beskrevet i {linkstart}sikkerhetstipsene ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Du gåt inn på siden via usikker HTTP.  Det er anbefales på det sterkeste at du setter opp serveren til å kreve HTTPS i stedet, som beskrevet i {linkstart}Sikkerhetstips ↗{linkend}.  Uten dette vil ikke viktig funksjonalitet som \"kopier til utklippstavle\" eller \"Service arbeidere\" virke!",
    "unknown text" : "ukjent tekst",
    "Hello world!" : "Hei, verden!",
    "sunny" : "solfylt",
    "Hello {name}, the weather is {weather}" : "Hallo {name}, været er {weather}",
    "Hello {name}" : "Hallo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dette er dine søketreff<script>alert(1)</script></strong>",
    "new" : "ny",
    "_download %n file_::_download %n files_" : ["last ned %n fil","last ned %n filer"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "En oppdatering foregår, lukking av denne siden kan forstyrre prosessen på enkelte systemer.",
    "Update to {version}" : "Oppdater til {version}",
    "An error occurred." : "En feil oppsto.",
    "Please reload the page." : "Last inn siden på nytt.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Oppdateringen var mislykket. For mer informasjon <a href=\"{url}\">se vår forum-artikkel</a> som beskriver dette problemet.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Oppdateringen mislyktes. Rapporter dette problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
    "Continue to {productName}" : "Fortsett til {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Oppdatering er vellykket. Går videre til {productName} om %n sekunder.","Oppdatering er vellykket. Går videre til {productName} om %n sekunder."],
    "Applications menu" : "Applikasjonsmeny",
    "More apps" : "Flere apper",
    "Currently open" : "For øyeblikket åpen",
    "_{count} notification_::_{count} notifications_" : ["{count} varsel","{count} varsler"],
    "Custom date range" : "Egendefinert datoperiode",
    "Pick start date" : "Velg start dato",
    "Pick end date" : "Velg sluttdato",
    "Search in date range" : "Søk innenfor valgte datoer",
    "Log in" : "Logg inn",
    "Logging in …" : "Logger inn…",
    "Server side authentication failed!" : "Autentisering mislyktes på serveren!",
    "Please contact your administrator." : "Kontakt administratoren din.",
    "Temporary error" : "Midlertidig feil",
    "Please try again." : "Vennligst prøv på nytt.",
    "An internal error occurred." : "En intern feil oppsto",
    "Please try again or contact your administrator." : "Prøv igjen eller kontakt en administrator.",
    "Login or email" : "Pålogging eller e-post",
    "Password" : "Passord",
    "Log in to {productName}" : "Logg på {productName}",
    "Wrong login or password." : "Feil pålogging eller passord.",
    "This account is disabled" : "Denne kontoen er deaktivert",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har detektert flere ugyldige påloggingsforsøk fra din IP-adresse. Derfor er din neste innlogging forsinket med opptil 30 sekunder.",
    "Log in with a device" : "Logg inn med en enhet",
    "Your account is not setup for passwordless login." : "Kontoen din er ikke satt opp med passordløs innlogging.",
    "Browser not supported" : "Nettleseren din støttes ikke!",
    "Passwordless authentication is not supported in your browser." : "Passordløs innlogging støttes ikke av nettleseren din.",
    "Your connection is not secure" : "Tilkoblingen din er ikke sikker",
    "Passwordless authentication is only available over a secure connection." : "Passordløs innlogging støttes kun over en sikker tilkobling.",
    "Reset password" : "Tilbakestill passord",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Hvis denne kontoen finnes, er det sendt en melding om tilbakestilling av passord til e-postadressen. Hvis du ikke mottar den, bekreft e-postadressen din og / eller logg inn, sjekk spam / søppelpostmappene dine eller spør din lokale administrasjon om hjelp.",
    "Couldn't send reset email. Please contact your administrator." : "Klarte ikke å sende e-post for tilbakestilling. Kontakt administratoren.",
    "Password cannot be changed. Please contact your administrator." : "Passordet kan ikke endres. Kontakt administratoren din.",
    "Back to login" : "Tilbake til innlogging",
    "New password" : "Nytt passord",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dine filer er kryptert. Det finnes ingen måte å få dine data tilbake etter at passordet er nullstilt. Hvis du er usikker på hva du skal gjøre, vennligst kontakt din administrator før du fortsetter. Er du helt sikker på at du vil fortsette?",
    "I know what I'm doing" : "Jeg vet hva jeg gjør",
    "Resetting password" : "Tilbakestill passord",
    "Recommended apps" : "Anbefalte apper",
    "Loading apps …" : "Laster apper ... ",
    "Could not fetch list of apps from the App Store." : "Kunne ikke hente liste med apper fra appbutikken. ",
    "Installing apps …" : "Installerer apper ... ",
    "App download or installation failed" : "Nedlasting eller installasjon av app feilet ",
    "Cannot install this app because it is not compatible" : "Kan ikke installere denne appen fordi den ikke er kompatibel",
    "Cannot install this app" : "Kan ikke installere denne appen",
    "Skip" : "Hopp over",
    "Install recommended apps" : "Installer anbefalte apper",
    "Schedule work & meetings, synced with all your devices." : "Planlegg jobb og møter, synkronisert med alle dine enheter.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Ha dine kollegaer og venner på en plass uten å lekke deres private info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app smidig integrert med Filer, Kontakter og Kalender.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, videosamtaler, skjermdeling, nettmøter og webkonferanser – i din nettleser og med mobilapper.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samarbeidsdokumenter, regneark og presentasjoner, bygget på Collabora Online.",
    "Distraction free note taking app." : "Distraksjonsfri notatapp.",
    "Search contacts" : "Søk etter kontakter",
    "Reset search" : "Tilbakestill søk",
    "Search contacts …" : "Søk etter kontakter…",
    "Could not load your contacts" : "Kunne ikke laste inn kontaktene dine",
    "No contacts found" : "Fant ingen kontakter",
    "Show all contacts" : "Vis alle kontakter",
    "Install the Contacts app" : "Installer appen Kontakter",
    "Loading your contacts …" : "Laster inn kontaktene dine…",
    "Looking for {term} …" : "Ser etter {term}…",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Søket starter når du begynner å skrive, og resultater kan nås med piltastene",
    "Search for {name} only" : "Søk kun etter {name}",
    "Start typing to search" : "Start å skrive for å søke",
    "Loading more results …" : "Laster flere resultater ...",
    "Load more results" : "Last flere resultater",
    "Search" : "Søk",
    "No results for {query}" : "Ingen resultater for {query}",
    "Press Enter to start searching" : "Trykk Enter for å starte søk",
    "An error occurred while searching for {type}" : "Det oppsto en feil ved søk etter {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Skriv minst {minSearchLength} bokstav for å søke","Skriv minst {minSearchLength} bokstaver for å søke"],
    "Forgot password?" : "Glemt passord?",
    "Back to login form" : "Tilbake til innloggingsskjema",
    "Back" : "Tilbake",
    "Login form is disabled." : "Innloggingskjemaet er deaktivert.",
    "Edit Profile" : "Endre profil",
    "The headline and about sections will show up here" : "Overskriften og om-seksjoner vil vises her",
    "You have not added any info yet" : "Du har ikke lagt inn noe informasjon ennå",
    "{user} has not added any info yet" : "{user} har ikke lagt inn noe informasjon ennå",
    "Error opening the user status modal, try hard refreshing the page" : "Feil ved åpning av bruker-status modal, prøv å laste inn siden på nytt med hard refresh",
    "Unified search" : "Enhetlig søk",
    "Search apps, files, tags, messages" : "Søk i apper, filer, tagger, meldinger",
    "Search {types} …" : "Søk {types} ...",
    "Apps and Settings" : "Apper og innstillinger",
    "Date" : "Dato",
    "Today" : "I dag",
    "Last 7 days" : "Siste 7 dager",
    "Last 30 days" : "Siste 30 dager",
    "This year" : "I år",
    "Last year" : "I fjor",
    "Search people" : "Søk etter personer",
    "Not found" : "Ikke funnet",
    "People" : "Mennesker",
    "Filter in current view" : "Filter i gjeldende visning",
    "Search in" : "Søk i",
    "Searching …" : "Søker ...",
    "No matching results" : "Ingen treff",
    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Mellom ${this.dateFilter.startFrom.toLocaleDateString()} og ${this.dateFilter.endAt.toLocaleDateString()}",
    "This browser is not supported" : "Denne nettleseren støttes ikke",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Nettleseren din støttes ikke. Vennligst oppgrader til en nyere versjon eller en støttet versjon.",
    "Continue with this unsupported browser" : "Fortsett med denne nettleseren som ikke støttes",
    "Supported versions" : "Støttede versjoner",
    "{name} version {version} and above" : "{name} versjon {version} og nyere",
    "Settings menu" : "Meny for innstillinger",
    "Avatar of {displayName}" : "{displayName} sin Avatar",
    "No" : "Nei",
    "Yes" : "Ja",
    "Choose {file}" : "Velg {file}",
    "Choose" : "Velg",
    "Copy to {target}" : "Kopier til {target}",
    "Copy" : "Kopier",
    "Move to {target}" : "Flytt til {target}",
    "Move" : "Flytt",
    "OK" : "OK",
    "Error loading message template: {error}" : "Feil ved lasting av meldingsmal: {error}",
    "read-only" : "skrivebeskyttet",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} fil konflikter"],
    "One file conflict" : "En filkonflikt",
    "New Files" : "Nye filer",
    "Already existing files" : "Allerede eksisterende filer",
    "Which files do you want to keep?" : "Hvilke filer vil du beholde?",
    "If you select both versions, the copied file will have a number added to its name." : "Hvis du velger begge versjonene vil den kopierte filen få et nummer lagt til i navnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Fortsett",
    "(all selected)" : "(alle valgt)",
    "({count} selected)" : "({count} valgt)",
    "Error loading file exists template" : "Feil ved lasting av \"filen eksisterer\"-mal",
    "Saving …" : "Lagrer...",
    "seconds ago" : "for få sekunder siden",
    "Connection to server lost" : "Mistet tilkobling til server",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem ved lasting av side, laster på nytt om %n sekund","Problem ved lasting av side, laster på nytt om %n sekunder"],
    "Add to a project" : "Legg til i et prosjekt",
    "Show details" : "Vis detaljer",
    "Hide details" : "Skjul detaljer",
    "Rename project" : "Endre navn på prosjekt",
    "Failed to rename the project" : "Klarte ikke å endre navnet på prosjektet",
    "Failed to create a project" : "Klarte ikke å opprettet prosjektet",
    "Failed to add the item to the project" : "Klarte ikke å koble objektet til prosjektet",
    "Connect items to a project to make them easier to find" : "Koble objekter til et prosjekt gjør dem enklere å finne",
    "Type to search for existing projects" : "Skriv for å søke etter eksisterende prosjekter",
    "New in" : "Ny i",
    "View changelog" : "Se endringslogg",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Bob-bob-passord",
    "Good password" : "Bra passord",
    "Strong password" : "Sterkt passord",
    "No action available" : "Ingen handling tilgjengelig",
    "Error fetching contact actions" : "Feil ved innhenting av kontakt-handlinger",
    "Close \"{dialogTitle}\" dialog" : "Lukk \"{dialogTitle}\" dialogen",
    "Non-existing tag #{tag}" : "Ikke-eksisterende merkelapp #{tag}",
    "Restricted" : "Begrenset",
    "Invisible" : "Usynlig",
    "Delete" : "Slett",
    "Rename" : "Gi nytt navn",
    "Collaborative tags" : "Samarbeidsmerkelapper",
    "No tags found" : "Ingen emneknagger funnet",
    "Personal" : "Personlig",
    "Accounts" : "Kontoer",
    "Apps" : "Apper",
    "Admin" : "Admin",
    "Help" : "Hjelp",
    "Access forbidden" : "Tilgang nektet",
    "Profile not found" : "Finner ikke profil",
    "The profile does not exist." : "Profilen finnes ikke",
    "Back to %s" : "Tilbake til %s",
    "Page not found" : "Siden ble ikke funnet",
    "The page could not be found on the server or you may not be allowed to view it." : "Siden ble ikke funnet på serveren, eller du har ikke tilgang til den.",
    "Too many requests" : "For mange forespørsler",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det var for mange forespørsler fra ditt nettverk. Prøv igjen senere eller kontakt din administrator hvis dette er en feil.",
    "Error" : "Feil",
    "Previous" : "Forrige",
    "Internal Server Error" : "Intern serverfeil",
    "The server was unable to complete your request." : "Serveren kunne ikke fullføre din forespørsel.",
    "If this happens again, please send the technical details below to the server administrator." : "Hvis dette skjer igjen, send de tekniske detaljene nedenfor til serveradministratoren.",
    "More details can be found in the server log." : "Flere detaljer finnes i serverloggen.",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Ekstern adresse: %s",
    "Request ID: %s" : "Forespørsels-ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Melding: %s",
    "File: %s" : "Fil: %s",
    "Line: %s" : "Linje: %s",
    "Trace" : "Sporing",
    "Security warning" : "Sikkerhetsadvarsel",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For informasjon om hvordan du skal konfigurere serveren skikkelig, les <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasjonen</a>.",
    "Create an <strong>admin account</strong>" : "Opprett en <strong>administrator-konto</strong>",
    "Show password" : "Vis passord",
    "Toggle password visibility" : "Vis passord av/på",
    "Storage & database" : "Lagring og database",
    "Data folder" : "Datamappe",
    "Configure the database" : "Sett opp databasen",
    "Only %s is available." : "Kun %s er tilgjengelig.",
    "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver flere PHP-moduler for å velge andre databasetyper.",
    "For more details check out the documentation." : "Henvend deg til dokumentasjonen for flere detaljer.",
    "Database account" : "Databasekonto",
    "Database password" : "Databasepassord",
    "Database name" : "Databasenavn",
    "Database tablespace" : "Database-tabellområde",
    "Database host" : "Databasevert",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Spesifiser portnr. sammen med servernavnet (f.eks., localhost:5432).",
    "Performance warning" : "Ytelsesadvarsel",
    "You chose SQLite as database." : "Du velger å bruke SQLite som database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite skal bare bli brukt for minimale- eller utvikler-installasjoner. I vanlig bruk anbefaler vi å bruke et annet bakstykke.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Hvis du bruker klienter for filsynkronisering så er bruk av SQLite absolutt ikke anbefalt.",
    "Install" : "Installer",
    "Installing …" : "Installerer ...",
    "Need help?" : "Trenger du hjelp?",
    "See the documentation" : "Se dokumentasjonen",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Det ser ut som at du forsøker å re installere Nextcloud. Filen CAN_INSTALL mangler imidlertid fra innstillingsmappen. Opprett filen CAN_INSTALL i innstillingsmappen for å fortsette.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kunne ikke fjerne CAN_INSTALL fra konfigurasjonsmappa. Vennligst fjern denne filen manuelt.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne appen krever JavaScript for å fungere korrekt. {linkstart}Aktiver JavaScript{linkend} og last siden på nytt.",
    "Skip to main content" : "Gå til hovedinnhold",
    "Skip to navigation of app" : "Gå til navigasjon av app",
    "Go to %s" : "Gå til %s",
    "Get your own free account" : "Få din egen gratis konto",
    "Connect to your account" : "Koble til kontoen din",
    "Please log in before granting %1$s access to your %2$s account." : "Logg inn før du tildeler %1$stilgang til din %2$skonto.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Hvis du ikke prøver å sette opp en ny enhet eller app, så er det noen som nå prøver å lure deg til å gi de tilgang til dine data. Stopp i så fall øyeblikkelig og kontakt din systemadministrator.",
    "App password" : "App passord",
    "Grant access" : "Gi tilgang",
    "Alternative log in using app password" : "Alternativ innlogging ved bruk av app passord",
    "Account access" : "Kontotilgang",
    "Currently logged in as %1$s (%2$s)." : "Logget inn som %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Du er i ferd med å tildele %1$s tilgang til din %2$skonto.",
    "Account connected" : "Konto er koblet",
    "Your client should now be connected!" : "Din klient skal nå være koblet til!",
    "You can close this window." : "Du kan lukke dette vinduet.",
    "This share is password-protected" : "Denne deling er beskyttet med passord",
    "The password is wrong or expired. Please try again or request a new one." : "Passordet er feil eller har utgått. Prøv igjen eller be om et nytt.",
    "Please type in your email address to request a temporary password" : "Oppgi e-post adresse for å få midlertidig passord",
    "Email address" : "E-post adresse",
    "Password sent!" : "Passord er sendt.",
    "You are not authorized to request a password for this share" : "Du mangler tillatelse for å etterspørre passord til deling. ",
    "Two-factor authentication" : "Tofaktor-autentisering",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Utvidet sikkerhet er tilgjengelig fo rdin konto. Velg en to-faktor for autentisering.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kunne ikke laste minst en av de aktiverte tofaktor metodene. Ta kontakt med administrasjonen din.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "To-faktor autentisering er aktivert men er ikke satt opp for din konto. Kontakt administrator for hjelp.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tofaktor autentisering er påkrevd, men er ikke satt opp for din konto. Vennligst gå videre for å sette opp tofaktor autentisering.",
    "Set up two-factor authentication" : "Opprett totrinns bekreftelse",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "To-faktor autentisering er aktivert men er ikke satt opp for din konto. Bruk en av dine sikkerhet koder for å logge inn eller kontakt administrator for hjelp.",
    "Use backup code" : "Bruker sikkerhetskopi kode",
    "Cancel login" : "Avbryt innlogging",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Utvidet sikkerhet håndheves for din konto. Velg hvilken tilbyder som skal brukes:",
    "Error while validating your second factor" : "Feil under validering av din andre faktor",
    "Access through untrusted domain" : "Nå gjennom ubetrodd domene",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontakt din administrator. Hvis du er en administrator, sett opp innstillingen \"trusted_domains\" i config/config.php som eksemplet i config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ytterligere informasojn om oppsett finnes i %1$sdokumentasjon%2$s.",
    "App update required" : "Oppdatering av app kreves",
    "%1$s will be updated to version %2$s" : "%1$soppdateres til versjon %2$s",
    "The following apps will be updated:" : "Følgende apper vil bli oppdatert:",
    "These incompatible apps will be disabled:" : "Disse ikke-kompatible appene vil bli deaktivert:",
    "The theme %s has been disabled." : "Temaet %s har blitt deaktivert.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Forsikre deg om at databasen, config-mappen og datamappen er blitt sikkerhetskopiert før du fortsetter.",
    "Start update" : "Start oppdatering",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For å unngå tidsavbrudd ved store installasjoner, kan du i stedet kjøre følgende kommando fra installasjonsmappen:",
    "Detailed logs" : "Detaljerte logger",
    "Update needed" : "Oppdatering er nødvendig",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bruk kommandolinjeoppdatereren siden du har en stor forekomst med mer enn 50 kontoer.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For hjelp, les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasjonen</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jeg vet at hvis jeg fortsetter oppdateringen via web-grensesnittet er det en mulighet for tap av data som følge av tidsavbrudd, men jeg har en sikkerhetskopi og vet hvordan jeg skal gjenopprette min installasjon hvis den feiler.",
    "Upgrade via web on my own risk" : "Oppgrader via web på min egen risikio",
    "Maintenance mode" : "Modus for vedlikehold",
    "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instansen er for øyeblikket i vedlikeholdsmodus, noe som kan vare en stund.",
    "This page will refresh itself when the instance is available again." : "Siden vil oppdatere seg selv når instans er tilgjengelig igjen.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren hvis denne meldingen var uventet eller ikke forsvinner.",
    "Please try again" : "Vennligst prøv igjen",
    "The user limit of this instance is reached." : "Brukergrensen på denne installasjonen er nådd.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Skriv inn abonnementsnøkkelen din i støtteappen for å øke brukergrensen. Dette gir deg også alle tilleggsfordeler som Nextcloud Enterprise tilbyr og anbefales på det sterkeste for driften i selskaper.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Nettserveren din er ikke riktig konfigurert for å løse \"{url}\". Dette er mest sannsynlig relatert til en webserverkonfigurasjon som ikke ble oppdatert for å levere denne mappen direkte. Sammenlign konfigurasjonen din med de tilsendte omskrivingsreglene i \".htaccess\" for Apache eller den oppgitte i dokumentasjonen for Nginx på sin {linkstart}dokumentasjonsside ↗{linkend}. På Nginx er det vanligvis linjene som starter med \"location ~\" som trenger en oppdatering.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Nettserveren din er ikke riktig konfigurert til å levere .woff2-filer. Dette er vanligvis et problem med Nginx-konfigurasjonen. For Nextcloud 15 trenger den en justering for også å levere .woff2-filer. Sammenlign Nginx-konfigurasjonen din med den anbefalte konfigurasjonen i {linkstart}dokumentasjonen ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP er satt opp feil for å nå systemets miljøvariable. Test med getenv(\"PATH\") gir tom respons.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Vennligst sjekk {linkstart}installasjonsdokumentasjonen ↗{linkend} for PHP-konfigurasjonsnotater og PHP-konfigurasjonen til serveren din, spesielt når du bruker php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ikke skrivbar konfigurasjon er aktivert. Dette hindrer endring av konfigurasjon via web-grensesnitt. Filen må gjøres skrivbar manuelt for hver oppdatering.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Du har ikke angitt eller bekreftet e-postserverkonfigurasjonen ennå. Gå over til {mailSettingsStart}Grunnleggende innstillinger{mailSettingsEnd} for å angi dem. Bruk deretter \"Send e-post\"-knappen under skjemaet for å bekrefte innstillingene dine.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Din database bruker ikke \"READ COMMITTED\" som isoleringsnivå for transaksjoner. Dette kan gi feil når flere hendelser skjer i parallell. Se dokumentasjon for din database og aktiver \"READ COMMITTED\" i din database for å unngå feil. ",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP modul \"fileinfo\" mangler. Denne er sterkt anbefalt for å finne korrekt MIME type for filer.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transaksjonsfillåsing er deaktivert, dette kan føre til problemer med løpsforholdene. Aktiver \"filelocking.enabled\" i config.php for å unngå disse problemene. Se {linkstart}dokumentasjonen ↗{linkend} for mer informasjon.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Sørg for å sette \"overwrite.cli.url\"-alternativet i config.php-filen til URL-en som brukerne dine hovedsakelig bruker for å få tilgang til denne Nextcloud. Forslag: \"{suggestedOverwriteCliURL}\". Ellers kan det være problemer med URL-generering via cron. (Det er imidlertid mulig at den foreslåtte URL-adressen ikke er URL-en som brukerne dine hovedsakelig bruker for å få tilgang til denne Nextcloud. Det beste er å dobbeltsjekke dette i alle fall.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Installasjonen din har ingen angitt standard telefonregion. Dette er nødvendig for å validere telefonnumrene i profilinnstillingene uten en landskode. For å tillate telefonnummer uten en landskode, vennligst legg til \"default_phone_region\" med den respektive  {linkstart}ISO 3166-1 koden↗{linkend} for regionen i konfigurasjonsfilen. ",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Det var ikke mulig å utføre cron jobben via CLI. Følgende tekniske feil har oppstått:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Siste bakgrunnsjobbkjøring kjørte {relativeTime}. Noe virker galt. {linkstart}Sjekk jobbinnstillingene i bakgrunnen ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Dette er den ustøttede fellesskapsbyggingen til Nextcloud. Gitt størrelsen på denne forekomsten kan ikke ytelse, pålitelighet og skalerbarhet garanteres. Push-varsler er begrenset for å unngå overbelastning av gratistjenesten vår. Finn ut mer om fordelene med Nextcloud Enterprise på {linkstart}https://nextcloud.com/enterprise{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Denne serveren har ingen fungerende internettforbindelse: Flere endepunkter kunne ikke nås. Dette betyr at noen av funksjonene som montering av ekstern lagring, varsler om oppdateringer eller installasjon av tredjepartsapper ikke vil fungere. Tilgang til filer eksternt og sending av e-postvarsler fungerer kanskje heller ikke. Etabler en tilkobling fra denne serveren til internett for å nyte alle funksjonene.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ingen minnebuffer er konfigurert. For å forbedre ytelsen, vennligst konfigurer en memcache, hvis tilgjengelig. Mer informasjon finner du i {linkstart}dokumentasjonen ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ingen passende kilde for tilfeldighet funnet av PHP, som er sterkt frarådd av sikkerhetsgrunner. Mer informasjon finner du i {linkstart}dokumentasjonen ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Du kjører for øyeblikket PHP {version}. Oppgrader PHP-versjonen din for å dra nytte av {linkstart}ytelses- og sikkerhetsoppdateringer fra PHP Group ↗{linkend} så snart distribusjonen din støtter det.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfigurasjonen av omvendt proxy-header er feil, eller du får tilgang til Nextcloud fra en klarert proxy. Hvis ikke, er dette et sikkerhetsproblem og kan tillate en angriper å forfalske IP-adressen sin som synlig for Nextcloud. Mer informasjon finner du i {linkstart}dokumentasjonen ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached er konfigurert som distribuert cache, men feil PHP-modul \"memcache\" er installert. \\OC\\Memcache\\Memcached støtter bare \"memcached\" og ikke \"memcache\". Se den {linkstart}memcachede wikien om begge modulene ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Noen filer har ikke bestått integritetskontrollen. Mer informasjon om hvordan du løser dette problemet finner du i {linkstart1}dokumentasjonen ↗{linkend}. ({linkstart2}Liste over ugyldige filer...{linkend} / {linkstart3}Skann på nytt...{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache-modulen er ikke riktig konfigurert. Se {linkstart}dokumentasjonen ↗{linkend} for mer informasjon.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funksjonen \"set_time_limit\" er ikke tilgjengelig. Dette kan resultere i at skript blir stoppet midt i kjøring, noe som knekker installasjonen din. Det anbefales sterkt å skru på denne funksjonen.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP-installasjon har ikke FreeType-støtte. Dette fører til knekte profilbilder og skadelidende innstillingsgrensesnitt.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Manglende indeks \"{indexName}\" i tabellen \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen mangler noen indekser. Å legge til indekser på store tabeller kan ta lang tid så de ble ikke lagt til automatisk. Ved å kjøre \"occ db:add-missing-indices\" legges de manglende indeksene til mens tjenesten fortsatt er tilgjengelig. Når indeksene er lagt til, er spørringer til  tabellene raskere.",
    "Missing primary key on table \"{tableName}\"." : "Mangler primærnøkkel i tabellen «{tableName}».",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Databasen mangler noen primærnøkler. På grunn av det faktum at det kan ta litt tid å legge til primærnøkler på store bord, ble de ikke lagt til automatisk. Ved å kjøre \"occ db:add-missing-primary-keys\" kan de manglende primærnøklene legges til manuelt mens forekomsten fortsetter å kjøre.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Mangler valgfri kolonne \"{columnName}\" i tabellen \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Databasen mangler noen valgfrie kolonner. Å legge til kolonner på store tabeller kan ta lang tid, så de ble ikke lagt til automatisk, ettersom de er valgfrie. Ved å kjøre \"occ db:add-missing-columns\" legges de manglende kolonnene til mens tjenesten fortsatt er tilgjengelig. Noen funksjoner kan få økt respons eller brukervennlighet når kolonnene er lagt til.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Din instans mangler anbefalte PHP moduler. For bedre ytelse og kompabilitet er det sterkt anbefalt at du installerer dem.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP-modulen \"imagick\" er ikke aktivert selv om tema-appen er det. For at favicongenerering skal fungere riktig, må du installere og aktivere denne modulen.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP-modulene \"gmp\" og/eller \"bcmath\" er ikke aktivert. Hvis du bruker WebAuthn passordløs autentisering, kreves disse modulene.",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Det virker som du kjører en 32-bit PHP-versjon. Nextcloud trenger 64-bit for å fungere bra. Vennligst oppgrader OS og PHP til 64-bit! For mer informasjon les {linkstart}dokumentasjonssiden ↗{linkend} om dette.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modulen php-imagick for denne instansen mangler støtte for SVG.\nFor økt kompatibilitet anbefales det å installere det.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Noen kolonner i databasen mangler en konvertering til big int. På grunn av det faktum at endring av kolonnetyper på store tabeller kunne ta litt tid ble de ikke endret automatisk. Ved å kjøre \"occ db:convert-filecache-bigint\" kan de ventende endringene brukes manuelt. Denne operasjonen må utføres mens forekomsten er frakoblet. For ytterligere detaljer, les {linkstart}dokumentasjonssiden om dette ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite brukes som database motor. For større installasjoner anbefaler vi at du bytter til en annen database motor.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Dette anbefales spesielt når du bruker skrivebordsklienten for filsynkronisering.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "For å migrere til en annen database, bruk kommandolinjeverktøyet: \"occ db:convert-type\", eller se {linkstart}dokumentasjonen ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "PHP er satt opp med mindre minne enn anbefalt minste verdi på 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Enkelte mapper er eid av annen bruker enn den webserveren kjører som. Dette kan kan oppstå hvis apper er installert manuelt. Sjekk eierskap og tillatelser på følgende mapper:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL brukes som database, men støtter ikke 4-byte tegn. For å kunne håndtere 4-byte-tegn (som emojis) uten problemer i filnavn eller kommentarer for eksempel, anbefales det å aktivere 4-byte-støtten i MySQL. For ytterligere detaljer, les {linkstart}dokumentasjonssiden om dette ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Denne instansen bruker en S3-basert objektlagring som primærlager. De opplastede filene blir lagret midlertidig på tjeneren og det er anbefalt å ha 50 GB ledig lagringsplass i det midlertidig lageret til PHP. Sjekk logger for fullstendige detaljer om filsti og ledig plass. Endre filstien til midlertidig lagringsplass i php.ini eller frigjør mer plass for å forbedre dette.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Den midlertidige katalogen for denne forekomsten peker til en enten ikke-eksisterende eller ikke-skrivbar katalog.",
    "Account name or email" : "Kontonavn eller e-postadresse",
    "Wrong username or password." : "Feil brukernavn eller passord.",
    "User disabled" : "Bruker deaktivert",
    "Username or email" : "Brukernavn eller e-post",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Melding om tilbakestilling av passord har blitt send til e-postadressen til denne kontoen. Hvis du ikke mottok den, burde du sjekke spam/søppelpost-mappene eller spørre din lokale administrator om hjelp.",
    "If it is not there ask your local administrator." : "Spør din lokale administrator hvis den ikke er der. ",
    "Start search" : "Start søk",
    "Press enter to start searching" : "Trykk enter for å starte søk",
    "Open settings menu" : "Åpne innstillinger-meny",
    "Settings" : "Innstillinger",
    "Show all contacts …" : "Vis alle kontakter…",
    "No files in here" : "Ingen filer her",
    "New folder" : "Ny mappe",
    "No more subfolders in here" : "Ingen flere mapper her",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
    "{newName} already exists" : "{newName} finnes allerede",
    "Error loading file picker template: {error}" : "Feil ved lasting av filvelger-mal: {error}",
    "Show list view" : "Vis listevisning",
    "Show grid view" : "Vis rutenett-visning",
    "Pending" : "Venter",
    "Home" : "Hjem",
    "Copy to {folder}" : "Kopier til {folder}",
    "Move to {folder}" : "Flytt til {folder}",
    "Authentication required" : "Autentisering påkrevd",
    "This action requires you to confirm your password" : "Denne handlingen krever at du bekrefter ditt passord",
    "Confirm" : "Bekreft",
    "Failed to authenticate, try again" : "Autentisering mislyktes, prøv igjen",
    "Users" : "Brukere",
    "The page could not be found on the server." : "Siden ble ikke funnet på serveren.",
    "Username" : "Brukernavn",
    "Database user" : "Databasebruker",
    "Confirm your password" : "Bekreft ditt passord",
    "App token" : "App-symbol",
    "Alternative log in using app token" : "Alternativ logg inn ved hjelp av app-kode",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Bruk kommandolinjeoppdatereren siden du har en stor installasjon med mer enn 50 brukere.",
    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Din eksterne adresse ble identifisert som \"{remoteAddress}\" and is brute-force strupet for øyeblikket, noe som bremser hastigheten av diverse forespørsler. Hvis den eksterne adressen ikke er din adresse, kan dette være en indikasjon på at en proxy ikke er korrekt konfigurert. Ytterligere informasjon kan finnes i {linkstart}documentation ↗{linkend}.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "Databasen brukes til låsing av transaksjonsfiler. For å forbedre ytelsen, vennligst konfigurer memcache, hvis tilgjengelig. Se {linkstart}dokumentasjonen ↗{linkend} for mer informasjon.",
    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 er nå avviklet i Nextcloud 27. Nextcloud 28 kan kreve minst PHP 8.1. Oppgrader til {linkstart}en av de offisielt støttede PHP-versjonene levert av PHP Group ↗{linkend} så snart som mulig.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Denne forekomsten kjører i feilsøkingsmodus. Bare aktiver dette for lokal utvikling og ikke i produksjonsmiljøer.",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Hvis denne kontoen eksisterer blir en melding om hvordan man resetter passordet sendt til kontoens epost.  Hvis du ikke mottar denne, sjekk epostadressen og/eller ditt brukernavn, sjekk søppelfilteret eller kontakt din lokale administrator for hjelp.",
    "Avatar of {fullName}" : "Avatar til {fullName}"
},
"nplurals=2; plural=(n != 1);");
